import _extends from '@babel/runtime/helpers/extends';
import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import React__default from 'react';
import './fileUpload.scss.js';
import SvgUpload from '../../assets/svgs/upload.svg.js';
import TextInput from '../TextInput/index.js';
import PropTypes from 'prop-types';

var readFileFromEvent = function readFileFromEvent(e) {
  return new Promise(function (resolve) {
    var file = e.target.files[0];

    if (file) {
      var fileReader = new FileReader();
      fileReader.readAsText(file);

      fileReader.onloadend = function () {
        resolve({
          fileName: file.name,
          contents: fileReader.result
        });
      };
    }
  });
};

var FileUpload = function FileUpload(_ref) {
  var onlyIconButton = _ref.onlyIconButton,
      disabled = _ref.disabled,
      className = _ref.className,
      label = _ref.label,
      placeholder = _ref.placeholder,
      error = _ref.error,
      value = _ref.value,
      onChange = _ref.onChange,
      textFieldProps = _ref.textFieldProps,
      uploadInputProps = _ref.uploadInputProps;

  var readFile = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(e) {
      var file;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return readFileFromEvent(e);

            case 2:
              file = _context.sent;
              onChange(file);
              e.target.value = '';

            case 5:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function readFile(_x) {
      return _ref2.apply(this, arguments);
    };
  }();

  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-upload-file ".concat(className, " ").concat(disabled ? 'Suc-disabled' : '')
  }, /*#__PURE__*/React__default.createElement(TextInput, _extends({
    type: "text",
    error: error,
    label: label,
    value: value,
    disabled: true,
    placeholder: placeholder,
    className: 'Suc-input-container'
  }, textFieldProps)), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-file-wrapper"
  }, /*#__PURE__*/React__default.createElement("input", _extends({
    className: 'file-input',
    disabled: disabled,
    type: "file",
    onChange: readFile
  }, uploadInputProps)), /*#__PURE__*/React__default.createElement(SvgUpload, {
    className: 'Suc-upload-svg'
  }), !onlyIconButton && /*#__PURE__*/React__default.createElement("div", {
    className: 'Suc-upload-text'
  }, "Upload")));
};

FileUpload.propTypes = {
  /** show button with text 'upload' or only upload icon */
  onlyIconButton: PropTypes.bool,

  /** disable uploading */
  disabled: PropTypes.bool,

  /** placeholder */
  placeholder: PropTypes.string,

  /** custom classname */
  className: PropTypes.string,

  /** custom props to the text field */
  textFieldProps: PropTypes.object,

  /** custom props to the file upload input */
  uploadInputProps: PropTypes.object
};
FileUpload.defaultProps = {
  onlyIconButton: false,
  className: '',
  disabled: false,
  textFieldProps: {},
  uploadInputProps: {}
};

export { FileUpload as default };
//# sourceMappingURL=index.js.map
